@@ -2,7 +2,7 @@ package Sweet::Home;
 use strict;
 use warnings;
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 1;
 
@@ -42,7 +42,11 @@ Nothing is better than feel at home. Where is the home? The home is where I can
 
 This package provides a set of features to make you feel comfortable when working with files and folders.
 
-It is just syntactic sugar on top of packages like L<'File::Basename'>, L<'File::Copy'>, L<'File::HomeDir'>, L<'File::Path'>, L<'File::Remove'>, L<'File::Spec'>, etc.
+It is just syntactic sugar on top of packages like L<File::Basename>, L<File::Copy>, L<File::HomeDir>, L<File::Path>, L<File::Remove>, L<File::Spec>, etc.
+
+=head1 CODE COVERAGE
+
+Code coverage metrics report available L<here|http://g14n.info/Sweet-Home-pm/code/coverage.html>
 
 =head1 CLASSES
 
@@ -62,7 +66,7 @@ It is just syntactic sugar on top of packages like L<'File::Basename'>, L<'File:
 
 =begin HTML
 
-<img src="https://raw.githubusercontent.com/fibo/Sweet-Home-pm/master/dia/Sweet-Home.svg" alt="Class diagram" />
+<img src="http://g14n.info/Sweet-Home-pm/dia/Sweet-Home.svg" alt="Class diagram" />
 
 =end HTML
 
